@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Steve Harris
+ *  Copyright (C) 2014 Steve Harris et al. (see AUTHORS)
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -29,12 +29,13 @@ extern "C" {
 #endif
 
 #include <stdarg.h>
+#include <sys/types.h>
 #ifdef _MSC_VER
-#define ssize_t SSIZE_T
-#define uint32_t unsigned __int32
-#else
-#include <stdint.h>
+#include <BaseTsd.h>
+typedef SSIZE_T ssize_t;
 #endif
+#include <stdint.h>
+
 
 #include "lo_types.h"
 #include "lo_errors.h"
@@ -55,7 +56,37 @@ extern "C" {
 typedef long double lo_hires;
 
 
+/**
+ * \brief A configuration struct for initializing \ref lo_server using lo_server_new_from_config().
+ *
+ * User code is responsible for allocating and deallocating memory
+ * pointed to by this struct, including strings for group, port,
+ * iface, ip, etc.  The struct and relevant fields will be copied by
+ * liblo when necessary, therefore it can be deallocated after use.
+ * The size field should be set to sizeof(lo_server_config).  Fields
+ * set to 0 shall be ignored.
+ */
+typedef struct {
+    size_t size;
+    const char *group;
+    const char *port;
+    const char *iface;
+    const char *ip;
+    int proto;
+    lo_err_handler err_handler;
+    void *err_handler_context;
+} lo_server_config;
 
+/**
+ * \brief Used with \ref lo_address_set_stream_slip() to specify whether sent
+ *        messages should be encoded with SLIP, and whether the encoding should
+ *        be single- or double-ENDed.
+ */
+typedef enum {
+	LO_SLIP_NONE   = 0,
+	LO_SLIP_SINGLE = 1,
+	LO_SLIP_DOUBLE = 2
+} lo_slip_encoding;
 
 /**
  * \brief Send a lo_message object to target targ
@@ -79,7 +110,7 @@ int lo_send_message(lo_address targ, const char *path, lo_message msg);
  * \param path The path to send the message to
  * \param msg  The bundle itself
  */
-int lo_send_message_from(lo_address targ, lo_server serv,
+int lo_send_message_from(lo_address targ, lo_server serv, 
      const char *path, lo_message msg);
 
 /**
@@ -97,7 +128,7 @@ int lo_send_bundle(lo_address targ, lo_bundle b);
  * lo_bundle_new() and lo_bundle_add_message() functions.
  *
  * \param targ The address to send the bundle to
- * \param serv The server socket to send the bundle from
+ * \param serv The server socket to send the bundle from 
  *              (can be NULL to use new socket)
  * \param b    The bundle itself
  */
@@ -106,7 +137,22 @@ int lo_send_bundle_from(lo_address targ, lo_server serv, lo_bundle b);
 /**
  * \brief Create a new lo_message object
  */
-lo_message lo_message_new();
+lo_message lo_message_new(void);
+
+/**
+ * \brief  Add one to a message's reference count.
+ *
+ * Messages are reference counted. If a message is multiply referenced,
+ * the message's counter should be incremented. It is automatically
+ * decremented by lo_message_free lo_message_free_recursive, with
+ * lo_message_free_recursive being the preferable method.
+ */
+void lo_message_incref(lo_message m);
+
+/**
+ * \brief Create a new lo_message object by cloning an already existing one
+ */
+lo_message lo_message_clone(lo_message m);
 
 /**
  * \brief Free memory allocated by lo_message_new() and any subsequent
@@ -274,9 +320,12 @@ int lo_message_add_nil(lo_message m);
 int lo_message_add_infinitum(lo_message m);
 
 /**
- * \brief  Returns the source (lo_address) of an incoming message.
+ * \brief  Returns the source (\ref lo_address) of an incoming message.
  *
- * Returns NULL if the message is outgoing. Do not free the returned address.
+ * Returns NULL if the message is outgoing. Do not free the returned
+ * address. This is usually called on the \ref lo_message passed to
+ * \ref lo_method_handler, to set up bidirectional communication.  See
+ * \ref example_tcp_echo_server.c for an example of this.
  */
 lo_address lo_message_get_source(lo_message m);
 
@@ -332,7 +381,7 @@ size_t lo_message_length(lo_message m, const char *path);
  * having the correct endianess and bit-packed structure.
  */
 void *lo_message_serialise(lo_message m, const char *path, void *to,
-                           size_t *size);
+			   size_t *size);
 
 /**
  * \brief  Deserialise a raw OSC message and return a new lo_message object.
@@ -398,24 +447,71 @@ char *lo_address_get_url(lo_address a);
 
 /**
  * \brief Set the Time-to-Live value for a given target address.
- *
+ * 
  * This is required for sending multicast UDP messages.  A value of 1
  * (the usual case) keeps the message within the subnet, while 255
  * means a global, unrestricted scope.
- *
+ * 
  * \param t An OSC address.
  * \param ttl An integer specifying the scope of a multicast UDP message.
- */
+ */ 
 void lo_address_set_ttl(lo_address t, int ttl);
 
 /**
  * \brief Get the Time-to-Live value for a given target address.
- *
+ * 
  * \param t An OSC address.
  * \return An integer specifying the scope of a multicast UDP message.
- */
+ */ 
 int lo_address_get_ttl(lo_address t);
 
+/**
+ * \brief Set the network interface to use for a given target address.
+ *
+ * The caller should specify either the iface or ip variable.  The IP,
+ * if specified, should match the same network family as the OSC
+ * address.  (That is, should correctly correspond to IPv4 or IPv6.)
+ * Typically the assigned network interface will only be used in the
+ * case of sending multicast messages.  It is recommended to use the
+ * if_nameindex POSIX function to get a list of network interface
+ * names.
+ *
+ * \param t An OSC address.
+ * \param iface The name of a network interface on the local system.
+ * \param ip The IP address of a network interface on the local system.
+ * \return 0 if the interface was successfully identified, or non-zero
+ *         otherwise.
+ */
+int lo_address_set_iface(lo_address t, const char *iface, const char *ip);
+
+/**
+ * \brief  Get the name of the network interface assigned to an OSC address.
+ *
+ * \param t An OSC address.
+ * \return A string pointer or 0 if no interface has been assigned.
+ *         Caller should not modify the provided string.  It is a
+ *         legal pointer until the next call to lo_address_set_iface
+ *         or lo_address_free.
+ */
+const char* lo_address_get_iface(lo_address t);
+
+/**
+ * \brief Set the TCP_NODELAY flag on outgoing TCP connections.
+ * \param t The address to set this flag for.
+ * \param enable Non-zero to set the flag, zero to unset it.
+ * \return the previous value of this flag.
+ */
+int lo_address_set_tcp_nodelay(lo_address t, int enable);
+
+/**
+ * \brief Set outgoing stream connections (e.g., TCP) to be
+ *        transmitted using the SLIP packetizing protocol.
+ * \param t The address to set this flag for.
+ * \param encoding Specify single- or double-ENDed SLIP, or disable SLIP.
+ * \return the previous value of this flag.
+ */
+int lo_address_set_stream_slip(lo_address t, lo_slip_encoding encoding);
+
 /**
  * \brief  Create a new bundle object.
  *
@@ -428,6 +524,16 @@ int lo_address_get_ttl(lo_address t);
  */
 lo_bundle lo_bundle_new(lo_timetag tt);
 
+/**
+ * \brief  Add one to a bundle's reference count.
+ *
+ * Bundles are reference counted. If a bundle is multiply referenced,
+ * the bundle's counter should be incremented. It is automatically
+ * decremented by lo_bundle_free lo_bundle_free_recursive, with
+ * lo_bundle_free_recursive being the preferable method.
+ */
+void lo_bundle_incref(lo_bundle b);
+
 /**
  * \brief  Adds an OSC message to an existing bundle.
  *
@@ -438,15 +544,70 @@ lo_bundle lo_bundle_new(lo_timetag tt);
  */
 int lo_bundle_add_message(lo_bundle b, const char *path, lo_message m);
 
+/**
+ * \brief  Adds an OSC bundle to an existing bundle.
+ *
+ * The child bundle passed is appended to the list of child bundles|messages in the parent bundle to be
+ * dispatched.
+ *
+ * \return 0 if successful, less than 0 otherwise.
+ */
+int lo_bundle_add_bundle(lo_bundle b, lo_bundle n);
+
 /**
  * \brief  Return the length of a bundle in bytes.
  *
- * Includes the marker and typetage length.
+ * Includes the marker and typetag length.
  *
  * \param b The bundle to be sized
  */
 size_t lo_bundle_length(lo_bundle b);
 
+/**
+ * \brief  Return the number of top-level elements in a bundle.
+ *
+ * \param b The bundle to be counted.
+ */
+unsigned int lo_bundle_count(lo_bundle b);
+
+/**
+ * \brief  Gets the element type contained within a bundle.
+ *
+ * Returns a lo_element_type at a given index within a bundle.
+
+ * \return The requested lo_element_type if successful, otherwise 0.
+ */
+lo_element_type lo_bundle_get_type(lo_bundle b, int index);
+
+/**
+ * \brief  Gets a nested bundle contained within a bundle.
+ *
+ * Returns a lo_bundle at a given index within a bundle.
+ *
+ * \return The requested lo_bundle if successful, otherwise 0.
+ */
+lo_bundle lo_bundle_get_bundle(lo_bundle b, int index);
+
+/**
+ * \brief  Gets a message contained within a bundle.
+ *
+ * Returns a lo_message at a given index within a bundle, and
+ * optionally the path associated with that message.
+ *
+ * \return The requested lo_message if successful, otherwise 0.
+ */
+lo_message lo_bundle_get_message(lo_bundle b, int index,
+                                 const char **path);
+
+/**
+ * \brief  Get the timestamp associated with a bundle.
+ *
+ * \param b The bundle for which the timestamp should be returned.
+ *
+ * \return The timestamp of the bundle as a lo_timetag.
+ */
+lo_timetag lo_bundle_get_timestamp(lo_bundle b);
+
 /**
  * \brief  Serialise the bundle object to an area of memory and return a
  * pointer to the serialised form.
@@ -470,9 +631,16 @@ void *lo_bundle_serialise(lo_bundle b, void *to, size_t *size);
 void lo_bundle_free(lo_bundle b);
 
 /**
- * \brief  Frees the memory taken by a bundle object and messages in the bundle.
+ * \brief  Frees the memory taken by a bundle object and its messages and nested bundles recursively.
  *
- * \param b The bundle, which may contain messages, to be freed.
+ * \param b The bundle, which may contain messages and nested bundles, to be freed.
+*/
+void lo_bundle_free_recursive(lo_bundle b);
+
+/**
+ * \brief  Obsolete, use lo_bundle_free_recursive instead.
+ *
+ * \param b The bundle, which may contain messages and nested bundles, to be freed.
 */
 void lo_bundle_free_messages(lo_bundle b);
 
@@ -555,7 +723,7 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
 
 /**
  * \brief Create a new server instance, and join a UDP multicast group.
- *
+ * 
  * \param group The multicast group to join.  See documentation on IP
  * multicast for the acceptable address range; e.g., http://tldp.org/HOWTO/Multicast-HOWTO-2.html
  * \param port If using UDP then NULL may be passed to find an unused port.
@@ -568,6 +736,57 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
 lo_server lo_server_new_multicast(const char *group, const char *port,
                                   lo_err_handler err_h);
 
+/**
+ * \brief Create a new server instance, and join a UDP multicast
+ * group, optionally specifying which network interface to use.
+ * Note that usually only one of iface or ip are specified. 
+ * 
+ * \param group The multicast group to join.  See documentation on IP
+ * multicast for the acceptable address range; e.g., http://tldp.org/HOWTO/Multicast-HOWTO-2.html
+ * \param port If using UDP then NULL may be passed to find an unused port.
+ * Otherwise a decimal port number or service name or may be passed.
+ * If using UNIX domain sockets then a socket path should be passed here.
+ * \param iface A string specifying the name of a network interface to
+ * use, or zero if not specified.
+ * \param ip A string specifying the IP address of a network interface
+ * to use, or zero if not specified.
+ * \param err_h An error callback function that will be called if there is an
+ * error in messge reception or server creation. Pass NULL if you do not want
+ * error handling.
+ */
+lo_server lo_server_new_multicast_iface(const char *group, const char *port,
+                                        const char *iface, const char *ip,
+                                        lo_err_handler err_h);
+
+/**
+ * \brief Create a new server instance, taking port and the optional
+ * multicast group IP from an URL string.
+ * 
+ * \param url The URL to specify the server parameters.
+ * \param err_h An error callback function that will be called if there is an
+ * error in messge reception or server creation. Pass NULL if you do not want
+ * error handling.
+ * \return A new lo_server instance.
+ */
+lo_server lo_server_new_from_url(const char *url,
+                                 lo_err_handler err_h);
+
+/**
+ * \brief Create a new server instance, using a configuration struct.
+ *
+ * \param config A pre-initialized config struct.  A pointer to it will not be kept.
+ * \return A new lo_server instance.
+ */
+lo_server lo_server_new_from_config(lo_server_config *config);
+
+/**
+ * \brief Enables or disables type coercion during message dispatch.
+ * \param server The server to toggle this option for.
+ * \param enable Non-zero to enable, or zero to disable type coercion.
+ * \return The previous value of this option.
+ */
+int lo_server_enable_coercion(lo_server server, int enable);
+
 /**
  * \brief Free up memory used by the lo_server object
  */
@@ -586,6 +805,21 @@ void lo_server_free(lo_server s);
  */
 int lo_server_wait(lo_server s, int timeout);
 
+/**
+ * \brief Wait on multiple servers for an OSC message to be received
+ *
+ * \param s An array of servers to wait for connections on.
+ * \param status An array to receive the status of each server.
+ * \param num_servers The number of servers in the array s.
+ * \param timeout A timeout in milliseconds to wait for the incoming packet.
+ * a value of 0 will return immediately.
+ *
+ * The return value is the number of servers with a message waiting or
+ * 0 if there is no message. If there is a message waiting you can now
+ * call lo_server_recv() to receive that message.
+ */
+int lo_servers_wait(lo_server *s, int *status, int num_servers, int timeout);
+
 /**
  * \brief Look for an OSC message waiting to be received
  *
@@ -599,6 +833,22 @@ int lo_server_wait(lo_server s, int timeout);
  */
 int lo_server_recv_noblock(lo_server s, int timeout);
 
+/**
+ * \brief Look for an OSC message waiting to be received on multiple servers
+ *
+ * \param s As array of servers to wait for connections on.
+ * \param recvd An array to store the number of bytes received by each server
+ * in array s.
+ * \param num_servers The number of servers in the array s.
+ * \param timeout A timeout in milliseconds to wait for the incoming packet.
+ * a value of 0 will return immediately.
+ *
+ * The return value is the total number of bytes received by all servers.
+ * The messages will be dispatched to a matching method if one is found.
+ */
+int lo_servers_recv_noblock(lo_server *s, int *recvd, int num_servers,
+                            int timeout);
+
 /**
  * \brief Block, waiting for an OSC message to be received
  *
@@ -620,13 +870,14 @@ int lo_server_recv(lo_server s);
  * matching message is received
  * \param user_data A value that will be passed to the callback function, h,
  * when its invoked matching from this method.
+ * \return A unique pointer identifying the method.  It should not be freed.
  */
 lo_method lo_server_add_method(lo_server s, const char *path,
                                const char *typespec, lo_method_handler h,
-                               void *user_data);
+                               const void *user_data);
 
 /**
- * \brief Delete an OSC method from the specifed server.
+ * \brief Delete an OSC method from the specified server.
  *
  * \param s The server the method is to be removed from.
  * \param path The OSC path of the method to delete. If NULL is passed the
@@ -636,6 +887,32 @@ lo_method lo_server_add_method(lo_server s, const char *path,
 void lo_server_del_method(lo_server s, const char *path,
                                const char *typespec);
 
+/**
+ * \brief Delete a specific OSC method from the specified server.
+ *
+ * \param s The server the method is to be removed from.
+ * \param m The lo_method identifier returned from lo_server_add_method for
+ *          the method to delete from the server.
+ * \return Non-zero if it was not found in the list of methods for the server.
+ */
+int lo_server_del_lo_method(lo_server s, lo_method m);
+
+/**
+ * \brief Add bundle notification handlers to the specified server.
+ *
+ * \param s The server the method is to be added to.
+ * \param sh The callback function that will be called before the messages
+ * of a bundle are dispatched
+ * \param eh The callback function that will be called after the messages
+ * of a bundle are dispatched
+ * \param user_data A value that will be passed to the user_data parameter
+ * of both callback functions.
+ */
+int lo_server_add_bundle_handlers(lo_server s,
+                                  lo_bundle_start_handler sh,
+                                  lo_bundle_end_handler eh,
+                                  void *user_data);
+
 /**
  * \brief Return the file descriptor of the server socket.
  *
@@ -672,19 +949,59 @@ int lo_server_get_protocol(lo_server s);
  */
 char *lo_server_get_url(lo_server s);
 
-/**
- * \brief Return true if there are scheduled events (eg. from bundles)
+/** 
+ * \brief Toggle event queue.
+ * If queueing is enabled, timetagged messages that are sent in
+ * advance of the current time will be put on an internal queue, and
+ * they will be dispatched at the indicated time.  By default,
+ * queueing is enabled.  Use this function to disable it, if it is
+ * desired to have a server process messages immediately.  In that
+ * case, use lo_message_get_timestamp() to get the message timestamp
+ * from within a method handler.
+ * \param s A liblo server
+ * \param queue_enabled Zero to disable queue, non-zero to enable.
+ * \param dispatch_remaining If non-zero, previously queued messages
+ *                           will be immediately dispatched when queue
+ *                           is disabled.
+ * \return The previous state of queue behaviour.  Zero if queueing
+ *         was previously disabled, non-zero otherwise.
+ */
+int lo_server_enable_queue(lo_server s, int queue_enabled,
+                           int dispatch_remaining);
+
+/** 
+ * \brief Return true if there are scheduled events (eg. from bundles) 
  * waiting to be dispatched by the server
  */
 int lo_server_events_pending(lo_server s);
 
-/**
+/** 
  * \brief Return the time in seconds until the next scheduled event.
  *
  * If the delay is greater than 100 seconds then it will return 100.0.
  */
 double lo_server_next_event_delay(lo_server s);
 
+/** 
+ * \brief Set the maximum message size accepted by a server.
+ *
+ * For UDP servers, the maximum message size cannot exceed 64k, due to
+ * the UDP transport specifications.  For TCP servers, this number may
+ * be larger, but be aware that one or more contiguous blocks of
+ * memory of this size may be allocated by liblo.  (At least one per
+ * connection.)
+ *
+ * \param s The server on which to operate.
+ * \param req_size The new maximum message size to request, 0 if it
+ * should not be modified, or -1 if it should be set to unlimited.
+ * Note that an unlimited message buffer may make your application
+ * open to a denial of service attack.
+ * \return The new maximum message size is returned, which may or may
+ * not be equal to req_size.  If -1 is returned, maximum size is
+ * unlimited.
+ */
+int lo_server_max_msg_size(lo_server s, int req_size);
+
 /**
  * \brief Return the protocol portion of an OSC URL, eg. udp, tcp.
  *
@@ -752,9 +1069,18 @@ uint32_t lo_blobsize(lo_blob b);
  *
  * \param str The string to test
  * \param p   The pattern to test against
+ * \return 1 if true, 0 otherwise.
  */
 int lo_pattern_match(const char *str, const char *p);
 
+/**
+ * \brief Test if a string contains any OSC pattern characters
+ *
+ * \param str The string to test
+ * \return 1 if true, 0 otherwise.
+ */
+int lo_string_contains_pattern(const char *str);
+
 /** \internal \brief the real send function (don't call directly) */
 int lo_send_internal(lo_address t, const char *file, const int line,
      const char *path, const char *types, ...);
@@ -762,8 +1088,8 @@ int lo_send_internal(lo_address t, const char *file, const int line,
 int lo_send_timestamped_internal(lo_address t, const char *file, const int line,
      lo_timetag ts, const char *path, const char *types, ...);
 /** \internal \brief the real lo_send_from() function (don't call directly) */
-int lo_send_from_internal(lo_address targ, lo_server from, const char *file,
-     const int line, const lo_timetag ts,
+int lo_send_from_internal(lo_address targ, lo_server from, const char *file, 
+     const int line, const lo_timetag ts, 
      const char *path, const char *types, ...);
 
 
@@ -849,8 +1175,6 @@ void lo_method_pp(lo_method m);
  * to all field names. */
 void lo_method_pp_prefix(lo_method m, const char *p);
 
-/** \brief Pretty-print a lo_server_thread object. */
-void lo_server_thread_pp(lo_server_thread st);
 /** @} */
 
 #ifdef __cplusplus
