@@ -38,6 +38,7 @@
 #include <string.h>
 #include <sys/stat.h>
 
+
 #ifdef __PLATFORM_WINDOWS__
 
   #ifndef __CHUNREAL_ENGINE__
@@ -53,6 +54,7 @@
 
   #include <unistd.h>
   #include <sys/ioctl.h>
+  #include <sys/time.h>
 
 #endif // #ifdef __PLATFORM_WINDOWS__
 
@@ -438,6 +440,62 @@ void ck_usleep( t_CKUINT microseconds )
 
 
 
+//-----------------------------------------------------------------------------
+// FYI timeval is defined in sys/time.h (non-windows)
+// FYI timeval is defined in winsock.h AND winsock2.h (windows)
+//     including winsock.h BEFORE winsock2.h could result in compiler errors
+//     (but not vice versa)
+//-----------------------------------------------------------------------------
+// typedef struct timeval { long tv_sec; long tv_usec; } timeval;
+//-----------------------------------------------------------------------------
+// name: ck_gettimeofday()
+// desc: get underlying operating system absolute time
+//-----------------------------------------------------------------------------
+int ck_gettimeofday( long * tv_sec, long * tv_usec, void * tzp )
+{
+    // zero out
+    *tv_sec = 0;
+    *tv_usec = 0;
+
+#ifndef __PLATFORM_WINDOWS__
+    // timeval
+    timeval tv;
+    // call on through
+    int retval = gettimeofday( &tv, tzp );
+    // check it
+    if( retval ) return retval;
+    // set return values
+    *tv_sec = tv.tv_sec;
+    *tv_usec = tv.tv_usec;
+    // return (success code)
+    return retval;
+
+#else // windows
+    // NOTE: some broken versions only have 8 trailing zero's, the correct epoch has 9 trailing zero's
+    // This magic number is the number of 100 nanosecond intervals since January 1, 1601 (UTC)
+    // until 00:00:00 January 1, 1970
+    static const uint64_t EPOCH = ((uint64_t) 116444736000000000ULL);
+
+    SYSTEMTIME  system_time;
+    FILETIME    file_time;
+    uint64_t    time;
+
+    GetSystemTime( &system_time );
+    SystemTimeToFileTime( &system_time, &file_time );
+    time =  ((uint64_t)file_time.dwLowDateTime )      ;
+    time += ((uint64_t)file_time.dwHighDateTime) << 32;
+
+    *tv_sec  = (long)((time - EPOCH) / 10000000L);
+    *tv_usec = (long)(system_time.wMilliseconds * 1000);
+
+    // return success
+    return 0;
+#endif
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 #if defined(__PLATFORM_APPLE__) && !defined(__CHIP_MODE__)
 //-----------------------------------------------------------------------------
@@ -482,6 +540,9 @@ ck_OSVersion ck_darwin_version()
 // https://stackoverflow.com/questions/11072804/how-do-i-determine-the-os-version-at-runtime-in-os-x-or-ios-without-using-gesta
 // https://en.wikipedia.org/wiki/Darwin_(operating_system)
 // Darwin operating system version to macOS release version
+// 25.x.x. macOS 16.x.x Tahoe
+// 24.x.x. macOS 15.x.x Sequoia
+// 23.x.x. macOS 14.x.x Sonoma
 // 22.x.x. macOS 13.x.x Ventura
 // 21.x.x. macOS 12.x.x Monterey
 // 20.x.x. macOS 11.x.x Big Sur
